#

##

###

###

    	Docker

    		systemctl restart docker

    	docker start
    		sudo su

    		from image
    			docker image list
    			docker run -it --name ubuntu-network-1 ubuntu-network

    				docker run -v .:/rollercoaster -it --name ubuntu-rollercoaster ubuntu-network:v1

    		from container
    			docker container ls --all
    			f"docker restart { container_id }"
    			f"docker exec -it { container_id } /bin/bash"

    				#
    				#	docker restart cd55e3c71e0b; docker exec -it cd55e3c71e0b /bin/bash